@@ -1,5 +1,32 @@
 package util ;
 
+use strict;
+
+use vars qw( $wantOK) ;
+$wantOK = 1 ;
+
+sub _ok
+{
+    my $no = shift ;
+    my $result = shift ;
+ 
+    print "not " unless $result ;
+    print "ok $no\n" ;
+    return $result;
+}
+
+sub import
+{
+    my $class = shift ;
+    my $no_want_ok = shift ;
+
+    $wantOK = 0 if $no_want_ok ;
+    if (! $no_want_ok)
+    {
+        *main::ok = \&_ok ;
+    }
+}
+
 package main ;
 
 use strict ;
@@ -43,22 +70,23 @@ $FA = 0 ;
 
     sub new
     {
-	my $self = shift ;
+        my $self = shift ;
         #my @files = () ;
         foreach (@_)
         {
             $_ = $basename ;
-            unlink $basename ;
+            1 while unlink $basename ;
             push @files, $basename ;
             ++ $basename ;
         }
- 	bless [ @files ], $self ;
+        bless [ @files ], $self ;
     }
 
     sub DESTROY
     {
-	my $self = shift ;
-	#unlink @{ $self } ;
+        my $self = shift ;
+        chmod 0777, @{ $self } ;
+        for (@$self) { 1 while unlink $_ } ;
     }
 
     END
@@ -258,14 +286,6 @@ sub addData
     return ($ret == 0) ;
 }
 
-sub ok
-{
-    my $no = shift ;
-    my $result = shift ;
- 
-    print "not " unless $result ;
-    print "ok $no\n" ;
-}
 
 
 # These two subs lifted directly from MLDBM.pm
@@ -323,4 +343,12 @@ sub fillout
     return $template ;
 }
 
+sub title
+{
+    #diag "" ;
+    ok(1, $_[0]) ;
+    #diag "" ;
+}
+
+
 1;
